==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/pt-PT/admin/users/general.php <==
<?php


return array(
    'activated_help_text' => 'Este utilizador pode fazer login',
    'activated_disabled_help_text' => 'Não pode editar o estado da activação para a sua própria conta.',
    'assets_user'       => 'Artigos alocados a :name',
    'bulk_update_warn'	=> 'Você está prestes a editar as propriedades de: user_count users. Observe que você não pode alterar seus próprios atributos do usuário usando este formulário e deve fazer edições para seu próprio usuário individualmente.',
    'bulk_update_help'	=> 'Este formulário permite que você atualize vários usuários de uma só vez. Apenas preencha os campos que você precisa alterar. Todos os campos deixados em branco permanecerão inalterados.',
    'current_assets'    => 'Artigos atribuidos atualmente a este utilizador',
    'clone'             => 'Clonar Utilizador',
    'contact_user'      => 'Contacto :name',
    'edit'              => 'Editar Utilizador',
    'filetype_info'     => 'Os tipos de ficheiro permitidos são png, gif, jpg, jpeg, doc, docx, pdf, txt, zip e rar.',
    'history_user'      => 'Histórico para :name',
	'info'				=> 'Info',
    'restore_user'		=> 'Clique aqui para restaurá-los.',
    'last_login'        => 'Último início de sessão',
    'ldap_config_text'  => 'As definições de configuração do LDAP podem ser encontradas em Administrador > Definições. A localização (opcional) selecionada vai ser defenida para todos os utilizadores importados.',
    'print_assigned'    => 'Imprimir todos atribuídos',
    'software_user'     => 'Software alocado a :name',
    'send_email_help'   => 'Você deve fornecer um endereço de e-mail para este usuário para enviar-lhe credenciais. Credenciais via e-mail só podem ser feitas na criação do usuário. As senhas são armazenadas em hash e não podem ser recuperadas depois de salvas.',
    'view_user'         => 'Ver Utilizador :name',
    'usercsv'           => 'Ficheiro CSV',
    'two_factor_admin_optin_help' => 'As configurações de admin actuais permitem a aplicação selectiva de autenticação de dois passos.  ',
    'two_factor_enrolled' => 'Dispositivo A2P Registado ',
    'two_factor_active'   => 'A2P Activa ',
    );

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/pt-PT/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Este utilizador pode fazer login',
    'activated_disabled_help_text' => 'Não pode editar o estado da activação para a sua própria conta.',
    'assets_user'       => 'Artigos alocados a :name',
    'bulk_update_warn'	=> 'Você está prestes a editar as propriedades de: user_count users. Observe que você não pode alterar seus próprios atributos do usuário usando este formulário e deve fazer edições para seu próprio usuário individualmente.',
    'bulk_update_help'	=> 'Este formulário permite que você atualize vários usuários de uma só vez. Apenas preencha os campos que você precisa alterar. Todos os campos deixados em branco permanecerão inalterados.',
    'current_assets'    => 'Artigos atribuidos atualmente a este utilizador',
    'clone'             => 'Clonar Utilizador',
    'contact_user'      => 'Contacto :name',
    'edit'              => 'Editar Utilizador',
    'filetype_info'     => 'Os tipos de ficheiro permitidos são png, gif, jpg, jpeg, doc, docx, pdf, txt, zip e rar.',
    'history_user'      => 'Histórico para :name',
    'info'				=> 'Info',
    'restore_user'		=> 'Clique aqui para restaurá-los.',
    'last_login'        => 'Último início de sessão',
    'ldap_config_text'  => 'As definições de configuração do LDAP podem ser encontradas em Administrador > Definições. A localização (opcional) selecionada vai ser defenida para todos os utilizadores importados.',
    'print_assigned'    => 'Imprimir todos atribuídos',
    'software_user'     => 'Software alocado a :name',
    'send_email_help'   => 'Você deve fornecer um endereço de e-mail para este usuário para enviar-lhe credenciais. Credenciais via e-mail só podem ser feitas na criação do usuário. As senhas são armazenadas em hash e não podem ser recuperadas depois de salvas.',
    'view_user'         => 'Ver Utilizador :name',
    'usercsv'           => 'Ficheiro CSV',
    'two_factor_admin_optin_help' => 'As configurações de admin actuais permitem a aplicação selectiva de autenticação de dois passos.  ',
    'two_factor_enrolled' => 'Dispositivo A2P Registado ',
    'two_factor_active'   => 'A2P Activa ',
    'user_deactivated'  => 'User is de-activated',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion' => 'WARNING:',
    'warning_deletion_information' => 'You are about to delete the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_asssets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
];
